.. highlight:: console

⚙️  Installation
================

It is recommended to install MOXελ inside a virtual environment.

1. Create a virtual environment:

    .. code-block::

        $ python -m venv <venvir_name>

2. Activate it:

    .. code-block::

        $ source <venvir_name>/bin/activate

3. Install ΜΟΧελ:

    .. code-block::

        (<venvir_name>) $ pip install pymoxel
